Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/arch/sun68k/stand convert from "bbinfo.h" to <dev/sun/su...



details:   https://anonhg.NetBSD.org/src/rev/f95d03b3048d
branches:  trunk
changeset: 526045:f95d03b3048d
user:      lukem <lukem%NetBSD.org@localhost>
date:      Wed Apr 24 01:40:25 2002 +0000

description:
convert from "bbinfo.h" to <dev/sun/sun_boot.h>

diffstat:

 sys/arch/sun68k/stand/bootxx/bootxx.c |  11 +++++----
 sys/arch/sun68k/stand/libsa/bbinfo.h  |  41 -----------------------------------
 2 files changed, 6 insertions(+), 46 deletions(-)

diffs (83 lines):

diff -r 1999811ade1a -r f95d03b3048d sys/arch/sun68k/stand/libsa/bbinfo.h
--- a/sys/arch/sun68k/stand/libsa/bbinfo.h      Wed Apr 24 01:40:14 2002 +0000
+++ /dev/null   Thu Jan 01 00:00:00 1970 +0000
@@ -1,41 +0,0 @@
-/*     $NetBSD: bbinfo.h,v 1.1 2001/12/15 23:09:51 fredette Exp $      */
-
-/*
- * Copyright (c) 1995, 1996 Carnegie-Mellon University.
- * All rights reserved.
- *
- * Author: Chris G. Demetriou
- *
- * Permission to use, copy, modify and distribute this software and
- * its documentation is hereby granted, provided that both the copyright
- * notice and this permission notice appear in all copies of the
- * software, derivative works or modified versions, and any portions
- * thereof, and that both notices appear in supporting documentation.
- *
- * CARNEGIE MELLON ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
- * CONDITION.  CARNEGIE MELLON DISCLAIMS ANY LIABILITY OF ANY KIND
- * FOR ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
- *
- * Carnegie Mellon requests users of this software to return to
- *
- *  Software Distribution Coordinator  or  Software.Distribution%CS.CMU.EDU@localhost
- *  School of Computer Science
- *  Carnegie Mellon University
- *  Pittsburgh PA 15213-3890
- *
- * any improvements or extensions that they make and grant Carnegie the
- * rights to redistribute these changes.
- */
-
-#define        MAXBLOCKNUM     64      /* enough for a 32K boot program (bs 512) */
-
-/* Magic string -- 32 bytes long (including the NUL) */
-#define        BBINFO_MAGIC    "NetBSD/sun68k bootxx           "
-#define        BBINFO_MAGICSIZE sizeof(BBINFO_MAGIC)
-
-struct bbinfo {
-       uint8_t bbi_magic[BBINFO_MAGICSIZE];
-       int32_t bbi_block_size;
-       int32_t bbi_block_count;
-       int32_t bbi_block_table[MAXBLOCKNUM];
-};



Home | Main Index | Thread Index | Old Index
diff -r 1999811ade1a -r f95d03b3048d sys/arch/sun68k/stand/bootxx/bootxx.c
--- a/sys/arch/sun68k/stand/bootxx/bootxx.c     Wed Apr 24 01:40:14 2002 +0000
+++ b/sys/arch/sun68k/stand/bootxx/bootxx.c     Wed Apr 24 01:40:25 2002 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: bootxx.c,v 1.2 2001/12/15 23:09:50 fredette Exp $ */
+/*     $NetBSD: bootxx.c,v 1.3 2002/04/24 01:40:25 lukem Exp $ */
 
 /*-
  * Copyright (c) 1998 The NetBSD Foundation, Inc.
@@ -49,9 +49,10 @@
 #include <sys/param.h>
 #include <machine/mon.h>
 
+#include <dev/sun/sun_boot.h>
+
 #include <stand.h>
 #include "libsa.h"
-#include "bbinfo.h"
 
 /*
  * This is the address where we load the second-stage boot loader.
@@ -59,13 +60,13 @@
 #define LOADADDR       0x4000
 
 /*
  * The contents of the bbinfo below are set by installboot(8)
  * to hold the filesystem data of the second-stage boot program
  * (typically `/ufsboot'): filesystem block size, # of filesystem
  * blocks and the block numbers themselves.
  */
-struct bbinfo bbinfo = {
-       { BBINFO_MAGIC },
+struct sun68k_bbinfo bbinfo = {
+       { SUN68K_BBINFO_MAGIC },
        0,
        MAXBLOCKNUM,
        { 0 }
@@ -59,13 +60,13 @@
 
 /*
- * The contents of the bbinfo below are set by installboot(8)
+ * The contents of the sun68k_bbinfo below are set by installboot(8)
  * to hold the filesystem data of the second-stage boot program
  * (typically `/ufsboot'): filesystem block size, # of filesystem